@@ -1,8 +1,6 @@
-import json
-
+import jwt
 from django.conf import settings
 
-from .crypto import AESCipherBase64
 from .serializers import PaymentSerializer
 
 
@@ -17,12 +15,17 @@ class Talar:
         self.access_key_id = settings.TALAR['access_key_id']
         self.access_key = settings.TALAR['access_key']
 
-        self.url = f'https://talar.app/p/{self.project_id}/order/classic/create/'
+        self.url = f'https://manage.talar.app/project/' \
+                   f'{self.project_id}/order/classic/create/'
 
     def create_payment_data(self, data: dict):
         talar_serializer = PaymentSerializer(data=data)
         talar_serializer.is_valid(raise_exception=True)
-        encrypted_data = AESCipherBase64(key=self.access_key).encrypt(
-            data=json.dumps(talar_serializer.validated_data)
+
+        encrypted_data = jwt.encode(
+            talar_serializer.validated_data,
+            self.access_key,
+            algorithm='HS256',
+            headers={'kid': self.access_key_id}
         )
-        return encrypted_data
+        return encrypted_data.decode("utf-8")
