@@ -6,6 +6,8 @@ class PaymentSerializer(serializers.Serializer):
     amount = serializers.CharField(max_length=255)
     currency = serializers.CharField(max_length=255)
     continue_url = serializers.CharField(max_length=255)
+    notify_url = serializers.CharField(max_length=255, required=False,
+                                       allow_blank=True)
     provider_code = serializers.CharField(max_length=255, required=False,
                                           allow_blank=True)
 
